@@ -8,7 +8,10 @@ mod paragraph;
 mod inline;
 mod escape;
 mod syntax_highlighter;
+mod icon;
+mod colors;
 
+use crate::utils::into_v16;
 use escape::*;
 use inline::render_inlines;
 use inline::tag::render_independent_tag;
@@ -24,7 +27,7 @@ pub fn render(content: &String) -> Result<String, ()> {
 
     let syntax_highlighter = self::syntax_highlighter::SyntaxHighlighter::new();
 
-    let mut u16_content = content.encode_utf16().collect::<Vec<u16>>();
+    let mut u16_content = into_v16(content);
     u16_content = escape_htmls(&u16_content);
 
     let mut lines = code_to_lines(&u16_content);
